@@ -27,6 +27,7 @@ def fun_control_init(
     PREFIX=None,
     TENSORBOARD_CLEAN=False,
     accelerator="auto",
+    acquisition_failure_strategy="random",
     check_finite=True,
     collate_fn_name=None,
     converters=None,
@@ -63,6 +64,7 @@ def fun_control_init(
     max_surrogate_points=30,
     metric_sklearn=None,
     metric_sklearn_name=None,
+    min_success_rate=0.0,
     noise=False,
     n_points=1,
     n_samples=None,
@@ -132,6 +134,10 @@ def fun_control_init(
             The accelerator to be used by the Lighting Trainer.
             It can be either "auto", "dp", "ddp", "ddp2", "ddp_spawn", "ddp_cpu", "gpu", "tpu".
             Default is "auto".
+        acquisition_failure_strategy (str):
+            Strategy to handle acquisition function failure.
+            Can be "random" to fall back to random sampling when the acquisition function fails.
+            Default is "random".
         check_finite (bool):
             When set True, stops training when the monitor becomes NaN or infinite.
             Default is True.
@@ -218,11 +224,15 @@ def fun_control_init(
         max_time (int):
             The maximum time in minutes.
         max_surrogate_points (int):
-            The maximum number of points in the surrogate model. Default is inf.
+            The maximum number of points in the surrogate model. Has no effect. Moved to surrogate_control_init().
         metric_sklearn (object):
             The metric object from the scikit-learn library. Default is None.
         metric_sklearn_name (str):
             The name of the metric object from the scikit-learn library. Default is None.
+        min_success_rate (float):
+            The minimum success rate for the Spot optimization to continue.
+            If the success rate falls below this value, a random point is proposed based on the acquisition_failure_strategy.
+            Default is 0.0.
         noise (bool):
             Whether the objective function is noiy or not. Default is False.
             Affects the repeat of the function evaluations.
@@ -367,6 +377,7 @@ def fun_control_init(
                 '_L_out': 11,
                 '_L_cond': None,
                 'accelerator': "auto",
+                'acquisition_failure_strategy': "random",
                 'check_finite': True,
                 'core_model': None,
                 'core_model_name': None,
@@ -389,6 +400,7 @@ def fun_control_init(
                 'metric_sklearn_name': None,
                 'metric_torch': None,
                 'metric_params': {},
+                'min_success_rate': 0.0,
                 'model_dict': {},
                 'noise': False,
                 'n_points': 1,
@@ -440,6 +452,7 @@ def fun_control_init(
         "_L_cond": _L_cond,
         "_torchmetric": _torchmetric,
         "accelerator": accelerator,
+        "acquisition_failure_strategy": acquisition_failure_strategy,
         "check_finite": check_finite,
         "collate_fn_name": collate_fn_name,
         "converters": converters,
@@ -482,6 +495,7 @@ def fun_control_init(
         "metric_sklearn_name": metric_sklearn_name,
         "metric_torch": None,
         "metric_params": {},
+        "min_success_rate": min_success_rate,
         "model_dict": {},
         "noise": noise,
         "n_points": n_points,
@@ -749,6 +763,10 @@ def surrogate_control_init(
     theta_init_zero=False,
     var_type=None,
     metric_factorial="canberra",
+    use_nystrom=False,
+    nystrom_m=20,
+    nystrom_seed=1234,
+    max_surrogate_points=30,
 ) -> dict:
     """Initialize surrogate_control dictionary.
 
@@ -793,6 +811,14 @@ def surrogate_control_init(
             Note: Will be set in the Spot class.
         metric_factorial (str):
             The metric to be used for the factorial design. Default is "canberra".
+        use_nystrom (bool):
+            Whether to use the Nystrom approximation or not. Default is False.
+        nystrom_m (int):
+            The number of Nystrom points to be used. Default is 20.
+        nystrom_seed (int):
+            The seed to use for the Nystrom approximation. Default is 1234.
+        max_surrogate_points (int):
+            The maximum number of points in the surrogate model. Has only an effect if use_nystrom is False. Default is 30.
 
     Returns:
         surrogate_control (dict):
@@ -836,6 +862,10 @@ def surrogate_control_init(
         "theta_init_zero": theta_init_zero,
         "var_type": var_type,
         "metric_factorial": metric_factorial,
+        "use_nystrom": use_nystrom,
+        "nystrom_m": nystrom_m,
+        "nystrom_seed": nystrom_seed,
+        "max_surrogate_points": max_surrogate_points,
     }
     return surrogate_control
 
